// main.c - driver routine for the example implementation for the tracer particle example from lecture 3
#include <stdio.h>
#include "tracer.h"

int main() 
{
    // define the parameters
    float m  = 1.0;
    float L  = 10.0;
    float x1 = 0.0;
    float x2 = L;
    float qE = 1.0;
    float alpha0 = 1.0;
    float dt = 0.01;

    // create the tracer structure and set its parameters
    struct Tracer tracer;
    tracer_set_parameters(&tracer, m, x1, x2, qE, alpha0, dt);

    // set initial state of the tracer
    float r0[DIM] = {0.0, 0.0};    
    float v0[DIM] = {0.0, 10.0};
    tracer_init(&tracer,r0,v0); 

    // print initial point
    printf("%f %f %f %f %f\n", tracer.t, tracer.r[0], tracer.r[1], r0[0], r0[1]);

    // take numsteps

    int numsteps = 1250;

    for (int i = 0; i < numsteps; ++i)
    { 
        // compute velocities and forces from positions r and rprev in tracer
        tracer_compute_force_and_velocity(&tracer);

        // take time step:
        tracer_time_step(&tracer);

        // compute theoretical trajectory
        float theory[DIM];
        tracer_compute_theory(theory, &tracer, r0, v0);

        // report computed and theoretical trajectory
        printf("%f %f %f %f %f\n", tracer.t, tracer.r[0], tracer.r[1], theory[0], theory[1]);
    }

    // done
    return 0;
}

