// tracer.h - interface to the example implementation for the tracer particle example from lecture 3
#ifndef _TRACERH_
#define _TRACERH_

// I don't always use preprocessor constants, but when I do...
#define DIM 2

struct Tracer {
    // parameters:
    float m;          // mass of the tracer particle
    float x1;         // lower bound on coordinates of the periodic simulation box (same in x and y)
    float x2;         // upper bound on coordinates of the periodic simulation box (same in x and y)
    float qE;         // strength of the force
    float alpha0;     // strength of the friction
    float dt;         // size of the time step
    // state:
    float t;          // current time
    float r[DIM];     // current position
    float rprev[DIM]; // previous position (used in verlet scheme)
    float f[DIM];     // force on the particle
    float v[DIM];     // current velocity (approximate)
};

void tracer_set_parameters(struct Tracer* tracer, float m, float x1, float x2, float qE, float alpha0, float dt);
void tracer_init(struct Tracer* tracer, float* r0, float* v0); 
void tracer_time_step(struct Tracer *tracer);
void tracer_compute_force_and_velocity(struct Tracer* tracer);
void tracer_compute_theory(float* rth, struct Tracer* tracer, float* r0, float* v0);

#endif
